@@ -1,5 +1,6 @@
 import sys
-import server, client
+from . import server
+from . import client
 
 if __name__ == '__main__':
     role = sys.argv[1]
